--------------------------------------------------------------------------------
-- Title   : Hermes registers definitions
-- Project : TimEX3
--------------------------------------------------------------------------------
-- Description : definition of the cPCI registers
--------------------------------------------------------------------------------
-- File     : cPCI_hermes_registers.vhdl
-- Revision : x.x.x
-- Created  : October 26, 2012
-- Updated  : March 08, 2013
--------------------------------------------------------------------------------
-- Author       : Jean-Paul Ricaud
-- Organization : Synchrotron Soleil
-- Web          : http://www.synchrotron-soleil.fr
-- Email        : jean-paul.ricaud@synchrotron-soleil.fr
--------------------------------------------------------------------------------
-- Copyright (C) 2012 - 2013 Synchrotron Soleil
--
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU Lesser General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU Lesser General Public License for more details.
--
-- You should have received a copy of the GNU Lesser General Public License
-- along with this program.  If not, see <http://www.gnu.org/licenses/>
--------------------------------------------------------------------------------
--
--------------------------------------------------------------------------------
-- Modifications :
--
--------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
package cPCI_hermes_registers is

  ------------------------------------------------------------------------------
  --Registers address
  ------------------------------------------------------------------------------
  constant c_add_boardid_reg  : std_logic_vector (9 downto 2) := "00000000"; -- board ID register
  constant c_add_firmware_reg : std_logic_vector (9 downto 2) := "00000001"; -- firmware's version register
  constant c_add_test_reg     : std_logic_vector (9 downto 2) := "00000010"; -- test register
  constant c_add_status_reg   : std_logic_vector (9 downto 2) := "00000011"; -- status register
  constant c_add_cmd_reg      : std_logic_vector (9 downto 2) := "00000100"; -- commands register
  constant c_add_register0    : std_logic_vector (9 downto 2) := "00000101"; -- register 0
  constant c_add_register1    : std_logic_vector (9 downto 2) := "00000110"; -- register 1
  constant c_add_register2    : std_logic_vector (9 downto 2) := "00000111"; -- register 2
  constant c_add_register3    : std_logic_vector (9 downto 2) := "00001000"; -- register 3
  constant c_add_register4    : std_logic_vector (9 downto 2) := "00001001"; -- register 4
  constant c_add_register5    : std_logic_vector (9 downto 2) := "00001010"; -- register 5
  constant c_add_register6    : std_logic_vector (9 downto 2) := "00001011"; -- register 6
  constant c_add_register7    : std_logic_vector (9 downto 2) := "00001100"; -- register 7
  constant c_add_register8    : std_logic_vector (9 downto 2) := "00001101"; -- register 8
  constant c_add_register9    : std_logic_vector (9 downto 2) := "00001110"; -- register 9
  constant c_add_register10   : std_logic_vector (9 downto 2) := "00001111"; -- register 10
  constant c_add_register11   : std_logic_vector (9 downto 2) := "00010000"; -- register 11
  constant c_add_register12   : std_logic_vector (9 downto 2) := "00010001"; -- register 12
  constant c_add_register13   : std_logic_vector (9 downto 2) := "00010010"; -- register 13
  constant c_add_foo_reg      : std_logic_vector (9 downto 2) := "00010011"; -- foo register, not used

  ------------------------------------------------------------------------------
  -- Registers
  ------------------------------------------------------------------------------
  --Write registers
  signal s_test_reg    : std_logic_vector (31 downto 0); -- test register
  signal s_status_reg  : std_logic_vector (31 downto 0); -- status register
  signal s_cmd_reg     : std_logic_vector (31 downto 0); -- command register ; s_CSW = "000000000000001"
  signal s_wRegister0  : std_logic_vector (31 downto 0); -- wRegister 0      ; s_CSW = "000000000000010"
  signal s_wRegister1  : std_logic_vector (31 downto 0); -- wRegister 1      ; s_CSW = "000000000000100"
  signal s_wRegister2  : std_logic_vector (31 downto 0); -- wRegister 2      ; s_CSW = "000000000001000"
  signal s_wRegister3  : std_logic_vector (31 downto 0); -- wRegister 3      ; s_CSW = "000000000010000"
  signal s_wRegister4  : std_logic_vector (31 downto 0); -- wRegister 4      ; s_CSW = "000000000100000"
  signal s_wRegister5  : std_logic_vector (31 downto 0); -- wRegister 5      ; s_CSW = "000000001000000"
  signal s_wRegister6  : std_logic_vector (31 downto 0); -- wRegister 6      ; s_CSW = "000000010000000"
  signal s_wRegister7  : std_logic_vector (31 downto 0); -- wRegister 7      ; s_CSW = "000000100000000"
  signal s_wRegister8  : std_logic_vector (31 downto 0); -- wRegister 8      ; s_CSW = "000001000000000"
  signal s_wRegister9  : std_logic_vector (31 downto 0); -- wRegister 9      ; s_CSW = "000010000000000"
  signal s_wRegister10 : std_logic_vector (31 downto 0); -- wRegister 10     ; s_CSW = "000100000000000"
  signal s_wRegister11 : std_logic_vector (31 downto 0); -- wRegister 11     ; s_CSW = "001000000000000"
  signal s_wRegister12 : std_logic_vector (31 downto 0); -- wRegister 12     ; s_CSW = "010000000000000"
  signal s_wRegister13 : std_logic_vector (31 downto 0); -- wRegister 13     ; s_CSW = "100000000000000"

  --Read registers
  signal s_rRegister0  : std_logic_vector (31 downto 0); -- rRegister 0      ; CSR = "000000000000001"
  signal s_rRegister1  : std_logic_vector (31 downto 0); -- rRegister 0      ; CSR = "000000000000010"
  signal s_rRegister2  : std_logic_vector (31 downto 0); -- rRegister 0      ; CSR = "000000000000100"
  signal s_rRegister3  : std_logic_vector (31 downto 0); -- rRegister 0      ; CSR = "000000000001000"
  signal s_rRegister4  : std_logic_vector (31 downto 0); -- rRegister 0      ; CSR = "000000000010000"
  signal s_rRegister5  : std_logic_vector (31 downto 0); -- rRegister 0      ; CSR = "000000000100000"
  signal s_rRegister6  : std_logic_vector (31 downto 0); -- rRegister 0      ; CSR = "000000001000000"
  signal s_rRegister7  : std_logic_vector (31 downto 0); -- rRegister 0      ; CSR = "000000010000000"
  signal s_rRegister8  : std_logic_vector (31 downto 0); -- rRegister 0      ; CSR = "000000100000000"
  signal s_rRegister9  : std_logic_vector (31 downto 0); -- rRegister 0      ; CSR = "000001000000000"
  signal s_rRegister10 : std_logic_vector (31 downto 0); -- rRegister 0      ; CSR = "000010000000000"
  signal s_rRegister11 : std_logic_vector (31 downto 0); -- rRegister 0      ; CSR = "000100000000000"
  signal s_rRegister12 : std_logic_vector (31 downto 0); -- rRegister 0      ; CSR = "001000000000000"
  signal s_rRegister13 : std_logic_vector (31 downto 0); -- rRegister 0      ; CSR = "010000000000000"

end package cPCI_hermes_registers;

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
package body cPCI_hermes_registers is

end package body cPCI_hermes_registers;

